@@ -1,5 +1,4 @@
-#ifndef ARTWORKPROVIDER_H
-#define ARTWORKPROVIDER_H
+#pragma once
 
 #include "pulpo/pulpo.h"
 #include <QImage>
@@ -13,7 +12,8 @@ class ArtworkFetcher : public QObject
 
 public:
     void fetch(FMH::MODEL data, PULPO::ONTOLOGY ontology);
-signals:
+
+Q_SIGNALS:
     void artworkReady(const QUrl &url);
     void finished();
 };
@@ -38,8 +38,4 @@ public:
 
     //    void updateArtwork(const int index, const QString &artwork);
     //    void startFetchingArtwork(FMH::MODEL_LIST data, PULPO::ONTOLOGY ontology);
-
-signals:
 };
-
-#endif // ARTWORKPROVIDER_H
